@@ -568,8 +568,9 @@ defSurv <- function(dtDefs = NULL,
       uniform = ,
 
       uniformInt = .checkUniform(newform),
+      trtAssign =  .checkCategorical(newform),
 
-      stop("Unkown distribution.")
+      stop("Unknown distribution.")
     )
 
     invisible(newvar)
